pub struct Client { /* private fields */ }Trait Implementations
Sourceimpl Client<FuchsiaTypes> for Client
impl Client<FuchsiaTypes> for Client
Sourcefn find_service(
&self,
uuid: Uuid,
) -> <FuchsiaTypes as GattTypes>::FindServicesFut
fn find_service( &self, uuid: Uuid, ) -> <FuchsiaTypes as GattTypes>::FindServicesFut
Find services by UUID on the peer.
This may cause as much as a full discovery of all services on the peer
if the stack deems it appropriate.
Service information should be up to date at the time returned.