pub struct LocalService { /* private fields */ }Trait Implementations
Sourceimpl From<LocalServiceRequestStream> for LocalService
impl From<LocalServiceRequestStream> for LocalService
Sourcefn from(value: LocalServiceRequestStream) -> Self
fn from(value: LocalServiceRequestStream) -> Self
Converts to this type from the input type.
Sourceimpl LocalService<FuchsiaTypes> for LocalService
impl LocalService<FuchsiaTypes> for LocalService
Sourcefn publish(&self) -> <FuchsiaTypes as ServerTypes>::ServiceEventStream
fn publish(&self) -> <FuchsiaTypes as ServerTypes>::ServiceEventStream
Publish the service.
Returns an EventStream providing Events to be processed by the local
service implementation.
Events will only be delivered to one ServiceEventStream at a time.
Calling publish while a previous ServiceEventStream is still active
will return a stream with only Err(AlreadyPublished).
Sourcefn notify(&self, characteristic: &Handle, data: &[u8], peers: &[PeerId])
fn notify(&self, characteristic: &Handle, data: &[u8], peers: &[PeerId])
Notify a characteristic.
Leave
peers empty to notify all peers who have configured
notifications. Peers that have not configured for notifications will
not be notified.Sourcefn indicate(
&self,
characteristic: &Handle,
data: &[u8],
peers: &[PeerId],
) -> <FuchsiaTypes as ServerTypes>::IndicateConfirmationStream
fn indicate( &self, characteristic: &Handle, data: &[u8], peers: &[PeerId], ) -> <FuchsiaTypes as ServerTypes>::IndicateConfirmationStream
Indicate on a characteristic.
Leave
peers empty to notify all peers who have configured
indications. Peers that have not configured for indications will
be skipped. Returns a stream which has items for each peer that
confirms the notification, and terminates when all peers have either
timed out or confirmed.Auto Trait Implementations
impl !Freeze for LocalService
impl !RefUnwindSafe for LocalService
impl Send for LocalService
impl Sync for LocalService
impl Unpin for LocalService
impl UnsafeUnpin for LocalService
impl !UnwindSafe for LocalService